@@ -56,3 +56,5 @@ from je_auto_control.utils.json.json_file import write_action_json
 
 # timeout
 from je_auto_control.utils.timeout.multiprocess_timeout import multiprocess_timeout
+# test record
+from je_auto_control.utils.test_record.record_test_result_class import test_record
